merlin.datasets package
=======================

.. automodule:: merlin.datasets
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   merlin.datasets.metadata
   merlin.datasets.iris
   merlin.datasets.mnist_digits
   merlin.datasets.spiral
   merlin.datasets.utils
